==> haskell-hopenpgp-2.9.5-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hOpenPGP
version:              2.9.5
visibility:           public
id:                   hOpenPGP-2.9.5-IkgNPoPwCCD3V5b0lLTC3b
key:                  hOpenPGP-2.9.5-IkgNPoPwCCD3V5b0lLTC3b
license:              MIT
copyright:            2012-2020  Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             https://salsa.debian.org/clint/hOpenPGP
synopsis:             native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581), plus ECC (RFC6637)

category:             Codec, Data
abi:                  c9f9c3274022fbe3e8289a762e7dbd6f
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.SignatureQualities
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify

hidden-modules:
    Codec.Encryption.OpenPGP.Internal
    Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
    Codec.Encryption.OpenPGP.Internal.Cryptonite
    Codec.Encryption.OpenPGP.Internal.HOBlockCipher
    Codec.Encryption.OpenPGP.SerializeForSigs
    Codec.Encryption.OpenPGP.Types.Internal.Base
    Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
    Codec.Encryption.OpenPGP.Types.Internal.PacketClass
    Codec.Encryption.OpenPGP.Types.Internal.PKITypes
    Codec.Encryption.OpenPGP.Types.Internal.Pkt
    Codec.Encryption.OpenPGP.Types.Internal.PrettyUtils
    Codec.Encryption.OpenPGP.Types.Internal.TK
    Codec.Encryption.OpenPGP.BlockCipher

import-dirs:          /usr/lib/ghc-8.10.3/site-local/hOpenPGP-2.9.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/hOpenPGP-2.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/hOpenPGP-2.9.5
hs-libraries:         HShOpenPGP-2.9.5-IkgNPoPwCCD3V5b0lLTC3b
depends:
    aeson-1.5.4.1-ILaja5MeYx9Akhe8KvMe35
    asn1-encoding-0.9.6-EacOTRyFEuzJhKz1ksuxbi
    attoparsec-0.13.2.4-EKPYlpfO7iaKzKjSdYGJKg base-4.14.1.0
    base16-bytestring-1.0.1.0-BkZ9AGRsXYM2rTBUmZ9iYL
    bifunctors-5.5.8-DNdRxgjbNuh515bixugkcc binary-0.8.8.0
    binary-conduit-1.3.1-KKheIuxQ9jy4XikpnU1tVK bytestring-0.10.12.0
    bz2-1.0.1.0-Iul3dJ3RFj98LKG5EaSTpC
    conduit-1.3.4-GlYrD0QALLOCrfTX89Nv78
    conduit-extra-1.3.5-H4HtsMaLNlkGwfBJQFrwul containers-0.6.2.1
    crypto-cipher-types-0.0.9-J2So9ZEqsLQG0ATekiDcSg
    cryptonite-0.27-8IAATyMqHP27LbEdhdFf3g
    errors-2.3.0-1jMMqiGok7nGSgO7igf65q
    hashable-1.3.0.0-EOCizfvfdumIxsTFbMrwv1
    incremental-parser-0.5.0.1-2hKYevwtcjL3wIdXW5sSB4
    ixset-typed-0.5-9e9lGMqZlxIJwCNOWCLlFA
    lens-4.19.2-A7vbUVtWOp9LirlFFzJs9P
    memory-0.15.0-E8yvrlcxsw5JtBytoHmuPe
    monad-loops-0.4.3-C0LVokhtCoUF1FVS5cJB0Q
    nettle-0.3.0-2wb6EXXCXxaFuXCUWnsipk
    network-uri-2.6.3.0-BPuNpM0S2bVH6RCCQDlxoo
    openpgp-asciiarmor-0.1.2-F1yxrwtbhnzGUtIUMzNnKL
    prettyprinter-1.7.0-msjiGKQ1v2H1yv3DP9396
    resourcet-1.2.4.2-9mUv7nXQDfYClNyJLbERsn
    split-0.2.3.4-IO8l01gOsVJ8ewvlVSygAx text-1.2.4.1 time-1.9.3
    time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
    transformers-0.5.6.2 unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV
    unordered-containers-0.2.13.0-CZ1lolzXKqq6TlKZBOiERd
    zlib-0.6.2.2-KXEELA86DXm4dzFxfFE1wE

haddock-interfaces:   /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html:         /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hopenpgp-2.9.5-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hOpenPGP
version:              2.9.5
visibility:           public
id:                   hOpenPGP-2.9.5-GZduaOPXnDEv6dSNCoEhh
key:                  hOpenPGP-2.9.5-GZduaOPXnDEv6dSNCoEhh
license:              MIT
copyright:            2012-2020  Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             https://salsa.debian.org/clint/hOpenPGP
synopsis:             native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581), plus ECC (RFC6637)

category:             Codec, Data
abi:                  bb72a4078db403be27c02278e954cb08
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.SignatureQualities
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify

hidden-modules:
    Codec.Encryption.OpenPGP.Internal
    Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
    Codec.Encryption.OpenPGP.Internal.Cryptonite
    Codec.Encryption.OpenPGP.Internal.HOBlockCipher
    Codec.Encryption.OpenPGP.SerializeForSigs
    Codec.Encryption.OpenPGP.Types.Internal.Base
    Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
    Codec.Encryption.OpenPGP.Types.Internal.PacketClass
    Codec.Encryption.OpenPGP.Types.Internal.PKITypes
    Codec.Encryption.OpenPGP.Types.Internal.Pkt
    Codec.Encryption.OpenPGP.Types.Internal.PrettyUtils
    Codec.Encryption.OpenPGP.Types.Internal.TK
    Codec.Encryption.OpenPGP.BlockCipher

import-dirs:          /usr/lib/ghc-8.10.3/site-local/hOpenPGP-2.9.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/hOpenPGP-2.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/hOpenPGP-2.9.5
hs-libraries:         HShOpenPGP-2.9.5-GZduaOPXnDEv6dSNCoEhh
depends:
    aeson-1.5.4.1-KEDpjWRN4PnwanaxkUvMN
    asn1-encoding-0.9.6-HRxqKF0IITL1cpXBSz8Ixk
    attoparsec-0.13.2.4-2xssqE3sbQuJGvEDlr5HPN base-4.14.1.0
    base16-bytestring-1.0.1.0-LpdmR3cRLho38k1NEAzqqP
    bifunctors-5.5.8-CKY60TzSRYn2XcgcKbMo1 binary-0.8.8.0
    binary-conduit-1.3.1-G8UJTclBdqn2kV5ioTbkng bytestring-0.10.12.0
    bz2-1.0.1.0-HnmVolBlTaN9Xrxe8QkW0L
    conduit-1.3.4-GYXXQ5mSZG22zBWVIpLtEN
    conduit-extra-1.3.5-FR13jiMBLqMJ8NBH6fj1GR containers-0.6.2.1
    crypto-cipher-types-0.0.9-J2So9ZEqsLQG0ATekiDcSg
    cryptonite-0.27-B0UUMEKgjEZDiYQNCuWUKu
    errors-2.3.0-1jMMqiGok7nGSgO7igf65q
    hashable-1.3.0.0-2hTNCY6h24LBZEHqacy9BZ
    incremental-parser-0.5.0.1-IZIEWVhseVJDAEqHemuSCU
    ixset-typed-0.5-GDmtqjHslv3HtxnzGmQhiJ
    lens-4.19.2-8FR05kWRsBy8cr95ogVwts
    memory-0.15.0-E8yvrlcxsw5JtBytoHmuPe
    monad-loops-0.4.3-C0LVokhtCoUF1FVS5cJB0Q
    nettle-0.3.0-2wb6EXXCXxaFuXCUWnsipk
    network-uri-2.6.3.0-1W9eALyPUrt5LXX3ZgvxGV
    openpgp-asciiarmor-0.1.2-DMJzgormXTE2J58eUiEHDs
    prettyprinter-1.7.0-IvX5FBfzJJzHAjPXm6w29x
    resourcet-1.2.4.2-3rlFMmcJnZq84GIl38QmMK
    split-0.2.3.4-22u0gnfTCz75CB9dqwkXJD text-1.2.4.1 time-1.9.3
    time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
    transformers-0.5.6.2 unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV
    unordered-containers-0.2.13.0-602GQuCMlfP9kZrcq9TZvH
    zlib-0.6.2.2-KXEELA86DXm4dzFxfFE1wE

haddock-interfaces:   /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html:         /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
